@@ -3,13 +3,13 @@ package RPi::WiringPi;
 use strict;
 use warnings;
 
-use parent 'RPi::WiringPi::Core';
+use parent 'RPi::WiringPi::Util';
 
 use RPi::WiringPi::Constant qw(:all);
 use RPi::WiringPi::LCD;
 use RPi::WiringPi::Pin;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 my $fatal_exit = 1;
 
@@ -34,22 +34,29 @@ sub new {
     $self = bless {%args}, $self;
 
     if (! $ENV{NO_BOARD}){
-        if (defined $self->{setup}){
+        if (! defined $self->{setup}) {
+            $self->SUPER::setup();
+            $self->gpio_scheme( 'WPI' );
+        }
+        else {
             if ($self->_setup =~ /^w/){
                 $self->SUPER::setup();
-                $self->pin_map('wiringPi');
+                $self->gpio_scheme('WPI');
             }
             elsif ($self->_setup =~ /^g/){
                 $self->SUPER::setup_gpio();
-                $self->pin_map('GPIO');
+                $self->gpio_scheme('BCM');
             }
             elsif ($self->_setup =~ /^s/){
                 $self->SUPER::setup_sys();
-                $self->pin_map('BCM');
+                $self->gpio_scheme('BCM');
             }
             elsif ($self->_setup =~ /^p/){
                 $self->SUPER::setup_phys();
-                $self->pin_map('PHYS GPIO');
+                $self->gpio_scheme('PHYS');
+            }
+            elsif ($self->_setup =~ /^n/){
+                $self->gpio_scheme('NULL');
             }
         }
     }
@@ -73,72 +80,6 @@ sub lcd {
     return $lcd;
 }
 
-# helper
-sub pin_map {
-    my ($self, $map) = @_;
-    if (defined $map){
-        $self->{pin_map} = $map;
-    }
-    return defined $self->{pin_map}
-        ? $self->{pin_map}
-        : 'NULL';
-}
-sub registered_pins {
-    my $self = shift;
-    my @pin_nums;
-    for (@{ $self->{registered_pins} }){
-        push @pin_nums, $_;
-    }
-    return @pin_nums;
-}
-sub register_pin {
-    my ($self, $pin) = @_;
-    my @current_pins = $self->registered_pins;
-    for (@current_pins){
-        if ($pin->num == $_->num){
-            my $num = $pin->num;
-            die "pin $num is already in use\n";
-        }
-    }
-    if (! defined $ENV{RPI_PINS}){
-        $ENV{RPI_PINS} = $pin->num;
-    }
-    else {
-        $ENV{RPI_PINS} = $ENV{RPI_PINS} . $pin->num;
-    }
-    push @{ $self->{registered_pins} }, $pin;
-}
-sub unregister_pin {
-    my ($self, $pin) = @_;
-    my @pins;
-    for ($self->registered_pins){
-        if ($_->num != $pin->num){
-            push @pins, $_;
-        }
-        else {
-            # disable the pin before unregistering
-            $pin->write(0);
-            $pin->mode(0);
-        }
-    }
-    if (@pins == $self->registered_pins){
-        warn "pin ". $pin->num ." is not registered, and can't be " .
-             "unregistered\n";
-    }
-    @{ $self->{registered_pins} } = @pins;
-    return $self->registered_pins;
-}
-sub cleanup {
-    my $self = shift;
-    for ($self->registered_pins){
-        $self->unregister_pin($_);
-        if ($_->mode){
-            my $num = $_->num;
-            warn "\npin $num couldn't be disabled/unregistered!\n";
-        }
-    }
-}
-
 # private
 
 sub _fatal_exit {
@@ -150,14 +91,15 @@ sub _setup {
 }
 sub _shutdown {
     # emergency die() handler cleanup
-    if (defined $ENV{RPI_PINS}){
+    if (defined $ENV{RPI_PINS}) {
         my @pins = split ',', $ENV{RPI_PINS};
-        for (@pins){
-            RPi::WiringPi::Core->write_pin($_, LOW);
-            RPi::WiringPi::Core->pin_mode($_, INPUT);
+        for (@pins) {
+            RPi::WiringPi::Core->write_pin( $_, LOW );
+            RPi::WiringPi::Core->pin_mode( $_, INPUT );
         }
     }
 }
+
 sub _vim{1;};
 1;
 __END__
@@ -174,21 +116,40 @@ functionality
 
     my $pi = RPi::WiringPi->new;
 
+    # board
+
     my $board = $pi->board;
+    my $revision = $pi->rev;
+    print "Raspberry Pi board revision: $revision"\n";
 
-    print "Raspberry Pi board revision: ". $board->rev ."\n";
+    # pin
 
-    my $gpio_pin_1 = $pi->pin(1);
-    my $gpio_pin_2 = $pi->pin(2);
+    my $pin = $pi->pin(5);
+    $pin->mode(OUTPUT);
+    $pin->write(ON);
 
-    $gpio_pin_1->mode(INPUT);
-    $gpio_pin_2->mode(OUTPUT);
+    my $num = $pin->num;
+    my $mode = $pin->mode;
+    my $state = $pin->read;
 
-    my $pin1_on = $gpio_pin_1->read;
+    # LCD
 
-    if ($pin1_on){
-        $gpio_pin_2->write(HIGH);
-    }
+    my $lcd = $pi->lcd;
+
+    $lcd->init(...);
+
+    # first column, first row
+    
+    $lcd->position(0, 0); 
+    $lcd->print("Pi rev: $revision");
+
+    # first column, second row
+    
+    $lcd->position(0, 1);
+    $lcd->print("pin $num... mode: $mode, state: $state");
+
+    $lcd->clear;
+    $lcd->display(OFF);
 
     $pi->cleanup;
 
@@ -203,15 +164,23 @@ L<wiringPi|http://wiringpi.com> library through the Perl wrapper
 L<RPi::WiringPi::Core|https://metacpan.org/pod/RPi::WiringPi::Core>
 module.
 
+This module is essentially a 'manager' for the sub-modules (ie. components).
+You can use the component modules directly, but retrieving components through
+this module instead has many benefits. We maintain a registry of pins and other
+data. We also trap C<$SIG{__DIE__}> and C<$SIG{INT}>, so that in the event of a
+crash, we can reset the Pi back to default settings, so components are not left
+in an inconsistent state. Component modules do none of these things.
+
+This module also calls the setup initialization routines automatically, where
+in the component modules, you have to do this manually. You also need to clean
+up after yourself.
+
 There are a basic set of constants that can be imported. See
 L<RPi::WiringPi::Constant>.
 
 L<wiringPi|http://wiringpi.com> must be installed prior to installing/using
 this module.
 
-By default, we use C<wiringPi>'s interpretation of GPIO pin mapping. See
-C<new> method to change this behaviour.
-
 =head1 OPERATIONAL METHODS
 
 =head2 new(%args)
@@ -227,7 +196,8 @@ Parameters:
 Optional. This option specifies which GPIO pin mapping (numbering scheme) to
 use. C<wiringPi> for wiringPi's mapping, C<physical> or C<system> to use the pin
 numbers labelled on the board itself, or C<gpio> use the Broadcom (BCM) pin
-numbers.
+numbers. You can also specify C<none> for testing purposes. This will bypass
+running the setup routines.
 
 See L<wiringPi setup reference|http://wiringpi.com/reference/setup> for
 important details on the differences.
@@ -269,55 +239,6 @@ attributes of the Raspberry Pi physical board itself.
 Returns a L<RPi::WiringPi::LCD> object, which allows you to fully manipulate
 LCD displays connected to your Raspberry Pi.
 
-=head2 cleanup()
-
-Resets all registered pins back to default settings (off). It's important that
-this method be called in each application.
-
-=head1 HELPER METHODS 
-
-These methods aren't normally needed by end-users. They're available for those
-who want to write their own libraries.
-
-=head2 pin_map()
-
-Returns the current pin mapping in use. Returns C<"NULL"> it has not yet been
-set.
-
-=head2 registered_pins()
-
-Returns an array of L<RPi::WiringPi::Pin> objects that are currently
-registered, and deemed to be in use.
-
-=head2 register_pin($pin_obj)
-
-Registers a GPIO pin within the system for error checking, and proper resetting
-of the pins in use when required.
-
-Parameters:
-
-=over 8
-
-=item    $pin_obj
-
-Mandatory: An object instance of L<RPi::WiringPi::Pin> class.
-
-=back
-
-=head2 unregister_pin($pin_obj)
-
-Exactly the opposite of C<register_pin()>.
-
-=head1 ENVIRONMENT VARIABLES
-
-There are certain environment variables available to aid in testing on
-non-Raspberry Pi boards.
-
-=head2 NO_BOARD
-
-Set to true, will bypass the C<wiringPi> board checks. False will re-enable
-them.
-
 =head1 IMPORTANT NOTES
 
 =over 4
