@@ -3,7 +3,7 @@ package RPi::WiringPi::LCD;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use parent 'RPi::WiringPi::Core';
 use RPi::WiringPi::Constant qw(:all);
@@ -13,7 +13,22 @@ sub new {
 }
 sub init {
     my ($self, %params) = @_;
-    my $fd = $self->lcd_init(%params);
+
+    my @required_args = qw(
+        rows cols bits rs strb
+        d0 d1 d2 d3 d4 d5 d6 d7
+    );
+    
+    my @args;
+    for (@required_args){
+        if (! defined $params{$_}) {
+            die "\n'$_' is a required param for Core::lcd_init()\n";
+        }
+        push @args, $params{$_};
+    }
+
+    my $fd = $self->lcd_init(@args);
+
     $self->_fd($fd);
 }
 sub home {
@@ -55,10 +70,6 @@ sub print {
     my ($self, $string) = @_;
     $self->lcd_puts($self->_fd, $string);
 }
-sub printf {
-    my ($self, $string) = @_;
-    $self->lcd_printf($self->_fd, $string);
-}
 sub _fd {
     my ($self, $fd) = @_;
     if (defined $fd){
@@ -204,17 +215,6 @@ Parameters:
 
 Mandatory: A string to display.
 
-=head2 printf($string)
-
-Displays a standard C<printf()> string to the LCD display, at the current
-cursor position.
-
-Parameters:
-
-    $string
-
-Mandatory: A string, optionally with C<printf()> formatting tags.
-
 =head1 AUTHOR
 
 Steve Bertrand, E<lt>steveb@cpan.orgE<gt>
